Index: pgadmin/include/dlg/dlgType.h
===================================================================
--- pgadmin/include/dlg/dlgType.h	(revision 7531)
+++ pgadmin/include/dlg/dlgType.h	(working copy)
@@ -32,6 +32,11 @@
 private:
     pgSchema *schema;
     pgType *type;
+
+#ifdef __WXMAC__
+    void OnChangeSize(wxSizeEvent &ev);
+#endif
+
     void OnTypeChange(wxCommandEvent &ev);
     void OnMemberAdd(wxCommandEvent &ev);
     void OnMemberRemove(wxCommandEvent &ev);
@@ -44,6 +49,9 @@
     void OnChangeMember(wxCommandEvent &ev);
 
     void showDefinition(int panel);
+    void showDefinitionComposite(bool showIt);
+    void showDefinitionEnum(bool showIt);
+    void showDefinitionExtern(bool showIt);
 
     wxArrayString memberTypes, memberSizes;
 
Index: pgadmin/dlg/dlgType.cpp
===================================================================
--- pgadmin/dlg/dlgType.cpp	(revision 7531)
+++ pgadmin/dlg/dlgType.cpp	(working copy)
@@ -26,6 +26,26 @@
 // pointer to controls
 #define rdbType                 CTRL_RADIOBOX("rdbType")
 
+#define stMembername            CTRL_STATIC("stMembername")
+#define stDatatype              CTRL_STATIC("stDatatype")
+#define stLength                CTRL_STATIC("stLength")
+#define stPrecision             CTRL_STATIC("stPrecision")
+#define stLabel                 CTRL_STATIC("stLabel")
+#define stInput                 CTRL_STATIC("stInput")
+#define stOutput                CTRL_STATIC("stOutput")
+#define stReceive               CTRL_STATIC("stReceive")
+#define stSend                  CTRL_STATIC("stSend")
+#define stTypmodin              CTRL_STATIC("stTypmodin")
+#define stTypmodout             CTRL_STATIC("stTypmodout")
+#define stIntLength             CTRL_STATIC("stIntLength")
+#define stVariable              CTRL_STATIC("stVariable")
+#define stDefault               CTRL_STATIC("stDefault")
+#define stElement               CTRL_STATIC("stElement")
+#define stDelimiter             CTRL_STATIC("stDelimiter")
+#define stAlignment             CTRL_STATIC("stAlignment")
+#define stStorage               CTRL_STATIC("stStorage")
+#define stPassedByValue         CTRL_STATIC("stPassedByValue")
+
 #define cbInput                 CTRL_COMBOBOX("cbInput")
 #define cbOutput                CTRL_COMBOBOX("cbOutput")
 #define cbReceive               CTRL_COMBOBOX("cbReceive")
@@ -49,9 +69,6 @@
 #define btnAddLabel             CTRL_BUTTON("btnAddLabel")
 #define btnRemoveLabel          CTRL_BUTTON("btnRemoveLabel")
 #define pnlDefinition           CTRL_PANEL("pnlDefinition")
-#define pnlDefinitionExtern     CTRL_PANEL("pnlDefinitionExtern")
-#define pnlDefinitionComposite  CTRL_PANEL("pnlDefinitionComposite")
-#define pnlDefinitionEnum       CTRL_PANEL("pnlDefinitionEnum")
 
 
 BEGIN_EVENT_TABLE(dlgType, dlgTypeProperty)
@@ -74,6 +91,10 @@
     EVT_COMBOBOX(XRCID("cbDatatype"),               dlgType::OnSelChangeTyp)
     EVT_TEXT(XRCID("txtMembername"),                dlgType::OnChangeMember)
     EVT_TEXT(XRCID("txtLength"),                    dlgType::OnSelChangeTypOrLen)
+
+#ifdef __WXMAC__
+    EVT_SIZE(                                       dlgType::OnChangeSize)
+#endif
 END_EVENT_TABLE();
 
 
@@ -96,6 +117,21 @@
 }
 
 
+#ifdef __WXMAC__
+void dlgType::OnChangeSize(wxSizeEvent &ev)
+{
+    lstMembers->SetSize(wxDefaultCoord, wxDefaultCoord,
+	    ev.GetSize().GetWidth(), ev.GetSize().GetHeight() - 340);
+    lstLabels->SetSize(wxDefaultCoord, wxDefaultCoord,
+	    ev.GetSize().GetWidth(), ev.GetSize().GetHeight() - 300);
+    if (GetAutoLayout())
+    {
+        Layout();
+    }
+}
+#endif
+
+
 void dlgType::OnChangeMember(wxCommandEvent &ev)
 {
     btnAddMember->Enable(!txtMembername->GetValue().Strip(wxString::both).IsEmpty() 
@@ -104,29 +140,78 @@
 
 void dlgType::showDefinition(int panel)
 {
-    pnlDefinitionExtern->Show(false);
-    pnlDefinitionComposite->Show(false);
-    pnlDefinitionEnum->Show(false);
+    showDefinitionComposite(panel == 0);
+    showDefinitionEnum(panel == 1);
+    showDefinitionExtern(panel == 2);
 
-    switch (panel)
-    {
-        case 0:
-            pnlDefinitionComposite->Show(true);
-            break;
-        case 1:
-            pnlDefinitionEnum->Show(true);
-            break;
-        case 2:
-            pnlDefinitionExtern->Show(true);
-            break;
-    }
+    // This fixes a UI glitch on MacOS X and Windows
+    // Because of the new layout code, the Privileges pane don't size itself properly
+    SetSize(GetSize().GetWidth()+1, GetSize().GetHeight());
+    SetSize(GetSize().GetWidth()-1, GetSize().GetHeight());
+ 
+    pnlDefinition->GetParent()->Layout();
+}
 
-    pnlDefinitionComposite->GetParent()->Layout();
-    // we don't need to call GetParent()->Layout() for all three panels
-    // because they all share the same parent
+
+void dlgType::showDefinitionComposite(bool showIt)
+{
+    lstMembers->Show(showIt);
+    stMembername->Show(showIt);
+    txtMembername->Show(showIt);
+    stDatatype->Show(showIt);
+    cbDatatype->Show(showIt);
+    stLength->Show(showIt);
+    txtLength->Show(showIt);
+    stPrecision->Show(showIt);
+    txtPrecision->Show(showIt);
+    btnAddMember->Show(showIt);
+    btnRemoveMember->Show(showIt);
 }
 
 
+void dlgType::showDefinitionEnum(bool showIt)
+{
+    lstLabels->Show(showIt);
+    stLabel->Show(showIt);
+    txtLabel->Show(showIt);
+    btnAddLabel->Show(showIt);
+    btnRemoveLabel->Show(showIt);
+}
+
+
+void dlgType::showDefinitionExtern(bool showIt)
+{
+    stInput->Show(showIt);
+    cbInput->Show(showIt);
+    stOutput->Show(showIt);
+    cbOutput->Show(showIt);
+    stReceive->Show(showIt);
+    cbReceive->Show(showIt);
+    stSend->Show(showIt);
+    cbSend->Show(showIt);
+    stTypmodin->Show(showIt);
+    cbTypmodin->Show(showIt);
+    stTypmodout->Show(showIt);
+    cbTypmodout->Show(showIt);
+    stIntLength->Show(showIt);
+    txtIntLength->Show(showIt);
+    stVariable->Show(showIt);
+    chkVariable->Show(showIt);
+    stDefault->Show(showIt);
+    txtDefault->Show(showIt);
+    stElement->Show(showIt);
+    cbElement->Show(showIt);
+    stDelimiter->Show(showIt);
+    txtDelimiter->Show(showIt);
+    stAlignment->Show(showIt);
+    cbAlignment->Show(showIt);
+    stStorage->Show(showIt);
+    cbStorage->Show(showIt);
+    stPassedByValue->Show(showIt);
+    chkByValue->Show(showIt);
+}
+
+
 void dlgType::OnTypeChange(wxCommandEvent &ev)
 {
     showDefinition(rdbType->GetSelection());
Index: pgadmin/ui/dlgType.xrc
===================================================================
--- pgadmin/ui/dlgType.xrc	(revision 7531)
+++ pgadmin/ui/dlgType.xrc	(working copy)
@@ -2,7 +2,7 @@
 <resource>
   <object class="wxDialog" name="dlgType">
     <title></title>
-    <size>218,300d</size>
+    <size>218,280d</size>
     <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
@@ -10,7 +10,7 @@
       <growablecols>0</growablecols>
       <object class="sizeritem">
         <object class="wxNotebook" name="nbNotebook">
-          <size>214,275d</size>
+          <size>214,255d</size>
           <selected>0</selected>
           <object class="notebookpage">
             <label>Properties</label>
@@ -121,423 +121,393 @@
             <object class="wxPanel" name="pnlDefinition">
               <object class="wxFlexGridSizer">
                 <cols>1</cols>
-                <rows>3</rows>
+                <rows>7</rows>
                 <vgap>5</vgap>
                 <hgap>5</hgap>
-                <growablerows>0,1,2</growablerows>
+                <growablerows>0,1,2,3,4,5,6</growablerows>
                 <growablecols>0</growablecols>
                 <object class="sizeritem">
-                  <object class="wxPanel" name="pnlDefinitionComposite">
-                    <object class="wxFlexGridSizer">
-                    <cols>1</cols>
-                    <rows>3</rows>
+                  <object class="wxListCtrl" name="lstMembers">
+                    <style>wxLC_REPORT|wxLC_SINGLE_SEL</style>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <rows>4</rows>
                     <vgap>5</vgap>
                     <hgap>5</hgap>
-                    <growablecols>0</growablecols>
-                    <growablerows>0</growablerows>
+                    <growablecols>1</growablecols>
                     <object class="sizeritem">
-                      <object class="wxListCtrl" name="lstMembers">
-                        <style>wxLC_REPORT|wxLC_SINGLE_SEL</style>
+                      <object class="wxStaticText" name="stMembername">
+                        <label>Member name</label>
                       </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtMembername">
+                      </object>
                       <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
                     </object>
                     <object class="sizeritem">
-                      <object class="wxFlexGridSizer">
-                        <cols>2</cols>
-                        <rows>4</rows>
-                        <vgap>5</vgap>
-                        <hgap>5</hgap>
-                        <growablecols>1</growablecols>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stMembername">
-                            <label>Member name</label>
-                          </object>
-                          <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxTextCtrl" name="txtMembername">
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stDatatype">
-                            <label>Data type</label>
-                          </object>
-                          <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxComboBox" name="cbDatatype">
-                            <content/>
-                            <style>wxCB_DROPDOWN</style>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stLength">
-                            <label>Length</label>
-                          </object>
-                          <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxTextCtrl" name="txtLength">
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stPrecision">
-                            <label>Precision</label>
-                          </object>
-                          <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxTextCtrl" name="txtPrecision">
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
+                      <object class="wxStaticText" name="stDatatype">
+                        <label>Data type</label>
                       </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbDatatype">
+                        <content/>
+                        <style>wxCB_DROPDOWN</style>
+                      </object>
                       <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
                     </object>
                     <object class="sizeritem">
-                      <object class="wxFlexGridSizer">
-                        <cols>3</cols>
-                        <rows>1</rows>
-                        <vgap>5</vgap>
-                        <hgap>5</hgap>
-                        <growablecols>0</growablecols>
-                        <object class="spacer">
-                          <size>0,0d</size>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxButton" name="btnAddMember">
-                            <label>Add/Change</label>
-                          </object>
-                          <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxButton" name="btnRemoveMember">
-                            <label>Remove</label>
-                          </object>
-                          <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
+                      <object class="wxStaticText" name="stLength">
+                        <label>Length</label>
                       </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
                     </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtLength">
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stPrecision">
+                        <label>Precision</label>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtPrecision">
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  </object>
                   <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                   <border>4</border>
                 </object>
                 <object class="sizeritem">
-                  <object class="wxPanel" name="pnlDefinitionEnum">
-                    <object class="wxFlexGridSizer">
-                      <cols>1</cols>
-                      <rows>3</rows>
-                      <vgap>5</vgap>
-                      <hgap>5</hgap>
-                      <growablerows>0</growablerows>
-                      <growablecols>0</growablecols>
-                      <object class="sizeritem">
-                        <object class="wxListCtrl" name="lstLabels">
-                          <pos>5,5d</pos>
-                          <size>200,155d</size>
-                          <style>wxLC_REPORT|wxLC_SINGLE_SEL</style>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                  <object class="wxFlexGridSizer">
+                    <cols>3</cols>
+                    <rows>1</rows>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>0</growablecols>
+                    <object class="spacer">
+                      <size>0,0d</size>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxButton" name="btnAddMember">
+                        <label>Add/Change</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxFlexGridSizer">
-                          <cols>2</cols>
-                          <rows>1</rows>
-                          <vgap>5</vgap>
-                          <hgap>5</hgap>
-                          <growablecols>1</growablecols>
-                          <object class="sizeritem">
-                            <object class="wxStaticText" name="stLabel">
-                              <label>Label</label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxTextCtrl" name="txtLabel">
-                            </object>
-                            <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxALL</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxButton" name="btnRemoveMember">
+                        <label>Remove</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxFlexGridSizer">
-                          <cols>3</cols>
-                          <rows>1</rows>
-                          <vgap>5</vgap>
-                          <hgap>5</hgap>
-                          <growablecols>0</growablecols>
-                          <object class="spacer">
-                            <size>2,2d</size>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxButton" name="btnAddLabel">
-                              <label>Add</label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxButton" name="btnRemoveLabel">
-                              <label>Remove</label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxALL</flag>
+                      <border>4</border>
+                    </object>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxListCtrl" name="lstLabels">
+                    <pos>5,5d</pos>
+                    <style>wxLC_REPORT|wxLC_SINGLE_SEL</style>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <rows>1</rows>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>1</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stLabel">
+                        <label>Label</label>
                       </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
                     </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtLabel">
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
                   <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                   <border>4</border>
                 </object>
                 <object class="sizeritem">
-                  <object class="wxPanel" name="pnlDefinitionExtern">
-                    <object class="wxFlexGridSizer">
-                      <cols>2</cols>
-                      <rows>14</rows>
-                      <vgap>5</vgap>
-                      <hgap>5</hgap>
-                      <growablecols>1</growablecols>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stInput">
-                          <label>Input function</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                  <object class="wxFlexGridSizer">
+                    <cols>3</cols>
+                    <rows>1</rows>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>0</growablecols>
+                    <object class="spacer">
+                      <size>2,2d</size>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxButton" name="btnAddLabel">
+                        <label>Add</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxComboBox" name="cbInput">
-                          <content/>
-                          <style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxButton" name="btnRemoveLabel">
+                        <label>Remove</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stOutput">
-                          <label>Output function</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <rows>14</rows>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>1</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stInput">
+                        <label>Input function</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxComboBox" name="cbOutput">
-                          <content/>
-                          <style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbInput">
+                        <content/>
+                        <style>wxCB_READONLY|wxCB_DROPDOWN</style>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stReceive">
-                          <label>Receive function</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stOutput">
+                        <label>Output function</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxComboBox" name="cbReceive">
-                      	<content/>
-                      	<style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbOutput">
+                        <content/>
+                        <style>wxCB_READONLY|wxCB_DROPDOWN</style>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stSend">
-                      	<label>Send function</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stReceive">
+                        <label>Receive function</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxComboBox" name="cbSend">
-                          <content/>
-                          <style>wxCB_READONLY|wxCB_DROPDOWN</style>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbReceive">
+                        <content/>
+                        <style>wxCB_READONLY|wxCB_DROPDOWN</style>
+                          </object>
+                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                          <border>4</border>
                         </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stSend">
+                    	<label>Send function</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stTypmodin">
-                      	<label>Typmod in func</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbSend">
+                        <content/>
+                        <style>wxCB_READONLY|wxCB_DROPDOWN</style>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxComboBox" name="cbTypmodin">
-                      	<content/>
-                      	<style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stTypmodin">
+                    	<label>Typmod in func</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stTypmodout">
-                      	<label>Typmod out func</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbTypmodin">
+                    	<content/>
+                    	<style>wxCB_READONLY|wxCB_DROPDOWN</style>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxComboBox" name="cbTypmodout">
-                      	<content/>
-                      	<style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stTypmodout">
+                    	<label>Typmod out func</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stIntLength">
-                          <label>Internal length</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbTypmodout">
+                    	<content/>
+                    	<style>wxCB_READONLY|wxCB_DROPDOWN</style>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxTextCtrl" name="txtIntLength">
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stIntLength">
+                        <label>Internal length</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stVariable">
-                          <label>Variable</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtIntLength">
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxCheckBox" name="chkVariable">
-                          <label></label>
-                          <checked>1</checked>
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stVariable">
+                        <label>Variable</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stDefault">
-                          <label>Default</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkVariable">
+                        <label></label>
+                        <checked>1</checked>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxTextCtrl" name="txtDefault">
-                        </object>
-                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stDefault">
+                        <label>Default</label>
                       </object>
-                      <object class="sizeritem">
-                        <object class="wxStaticText" name="stElement">
-                          <label>Element</label>
-                        </object>
-                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                        <border>4</border>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtDefault">
                       </object>
-                      <object class="sizeritem">
-                            <object class="ctlComboBox" name="cbElement">
-                              <content/>
-                              <style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                            </object>
-                            <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stElement">
+                        <label>Element</label>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                          <object class="ctlComboBox" name="cbElement">
+                            <content/>
+                            <style>wxCB_READONLY|wxCB_DROPDOWN</style>
                           </object>
-                          <object class="sizeritem">
-                            <object class="wxStaticText" name="stDelimiter">
-                              <label>Delimiter</label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxTextCtrl" name="txtDelimiter">
-                            </object>
-                            <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxStaticText" name="stAlignment">
-                              <label>Alignment</label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxComboBox" name="cbAlignment">
-                              <content>
-                                <item/>
-                                <item>char</item>
-                                <item>int2</item>
-                                <item>int4</item>
-                                <item>double</item>
-                              </content>
-                              <style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                            </object>
-                            <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxStaticText" name="stStorage">
-                              <label>Storage</label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxComboBox" name="cbStorage">
-                              <content>
-                                <item/>
-                                <item>PLAIN</item>
-                                <item>EXTERNAL</item>
-                                <item>EXTENDED</item>
-                                <item>MAIN</item>
-                              </content>
-                              <selection>0</selection>
-                              <style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                            </object>
-                            <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxStaticText" name="stPassedByValue">
-                              <label>Passed by value</label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
-                          <object class="sizeritem">
-                            <object class="wxCheckBox" name="chkByValue">
-                              <label></label>
-                            </object>
-                            <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                            <border>4</border>
-                          </object>
+                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                          <border>4</border>
                         </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stDelimiter">
+                        <label>Delimiter</label>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtDelimiter">
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stAlignment">
+                        <label>Alignment</label>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbAlignment">
+                        <content>
+                          <item/>
+                          <item>char</item>
+                          <item>int2</item>
+                          <item>int4</item>
+                          <item>double</item>
+                        </content>
+                        <style>wxCB_READONLY|wxCB_DROPDOWN</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stStorage">
+                        <label>Storage</label>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbStorage">
+                        <content>
+                          <item/>
+                          <item>PLAIN</item>
+                          <item>EXTERNAL</item>
+                          <item>EXTENDED</item>
+                          <item>MAIN</item>
+                        </content>
+                        <selection>0</selection>
+                        <style>wxCB_READONLY|wxCB_DROPDOWN</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stPassedByValue">
+                        <label>Passed by value</label>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkByValue">
+                        <label></label>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
                   <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                   <border>4</border>
